[前][次][番号順一覧][スレッド一覧]

ruby-changes:41075

From: normal <ko1@a...>
Date: Wed, 16 Dec 2015 16:25:49 +0900 (JST)
Subject: [ruby-changes:41075] normal:r53150 (trunk): test/ruby/test_io.rb: fix spelling errors

normal	2015-12-16 16:25:38 +0900 (Wed, 16 Dec 2015)

  New Revision: 53150

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=revision&revision=53150

  Log:
    test/ruby/test_io.rb: fix spelling errors

  Modified files:
    trunk/ChangeLog
    trunk/test/ruby/test_io.rb
Index: ChangeLog
===================================================================
--- ChangeLog	(revision 53149)
+++ ChangeLog	(revision 53150)
@@ -1,3 +1,7 @@ https://github.com/ruby/ruby/blob/trunk/ChangeLog#L1
+Wed Dec 16 16:17:34 2015  Eric Wong  <e@8...>
+
+	* test/ruby/test_io.rb: fix spelling errors
+
 Wed Dec 16 16:04:49 2015  Eric Wong  <e@8...>
 
 	* NEWS: note IO#fadvise change [ruby-core:72168]
Index: test/ruby/test_io.rb
===================================================================
--- test/ruby/test_io.rb	(revision 53149)
+++ test/ruby/test_io.rb	(revision 53150)
@@ -2531,7 +2531,7 @@ End https://github.com/ruby/ruby/blob/trunk/test/ruby/test_io.rb#L2531
 
     fs = nil
     if uname[:sysname] == 'Linux'
       # [ruby-dev:45703] Old Linux's fadvice() doesn't work on tmpfs.
       mount = `mount`
       mountpoints = []
       mount.scan(/ on (\S+) type (\S+) /) {
@@ -3007,10 +3007,10 @@ End https://github.com/ruby/ruby/blob/trunk/test/ruby/test_io.rb#L3007
     with_pipe do |r,w|
       # Linux 2.6.15 and earlier returned EINVAL instead of ESPIPE
       assert_raise(Errno::ESPIPE, Errno::EINVAL) {
-        r.advise(:willneed) or skip "fadvice(2) is not implemented"
+        r.advise(:willneed) or skip "fadvise(2) is not implemented"
       }
       assert_raise(Errno::ESPIPE, Errno::EINVAL) {
-        w.advise(:willneed) or skip "fadvice(2) is not implemented"
+        w.advise(:willneed) or skip "fadvise(2) is not implemented"
       }
     end
   end if /linux/ =~ RUBY_PLATFORM
@@ -2531,7 +2531,7 @@ End https://github.com/ruby/ruby/blob/trunk/test/ruby/test_io.rb#L2531
     fs = nil
     if uname[:sysname] == 'Linux'
-      # [ruby-dev:45703] Old Linux's fadvice() doesn't work on tmpfs.
+      # [ruby-dev:45703] Old Linux's fadvise() doesn't work on tmpfs.
       mount = `mount`
       mountpoints = []

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]